@@ -4,6 +4,7 @@ import os
 from typing import List, Optional, Tuple, Union
 
 import boto3
+import einops
 import gcsfs
 import torch
 from nowcasting_dataset.config.model import Configuration
@@ -335,6 +336,9 @@ class SatFlowDataset(NetCDFDataset):
         x[SATELLITE_DATA] = x.pop("satellite")
         x["hrv_" + SATELLITE_DATA] = x.pop("hrvsatellite")
 
+        # Zero out NaN PV and GSP Yield
+        x = self.zero_out_nan_pv_systems(x)
+
         return x, target
 
     def add_encodings(
@@ -359,6 +363,7 @@ class SatFlowDataset(NetCDFDataset):
         Returns:
             x dictionary with the added/updated keys
         """
+
         if key + "_position_encoding" in batch:
             past_encoding = batch[key + "_position_encoding"][:, :, :current_timestep_index]
             x[key] = torch.cat([x[key], past_encoding], dim=1)
@@ -367,6 +372,32 @@ class SatFlowDataset(NetCDFDataset):
                 x[key + "_query"] = future_encoding
         return x
 
+    def zero_out_nan_pv_systems(self, x: dict) -> dict:
+        """
+        Zeros out NaN PV systems and their position encodings
+
+        This takes advantage of the fact that NaN values for PV and GSP systems are always at the
+        end of the example, so just need to find the first one and can zero out everything after.
+
+        This should be used after the position encodings are appended, so that it zeros out all the
+        channels as well
+
+        Args:
+            x: dictionary of inputs
+
+        Returns:
+            The dictionary x with the PV systems zeroed out and position encodings zeroed as well
+        """
+
+        for key in [PV_YIELD, GSP_YIELD]:
+            if key in x:
+                mask = torch.isnan(x[key][:, 0, :])  # Only looking at the yield
+                mask = einops.repeat(mask, "b id -> b t id", t=x[key].shape[1])
+                # Zero out for all entries related to
+                x[key][mask] = 0.0
+
+        return x
+
 
 def worker_init_fn(worker_id):
     """Configures each dataset worker process.
